#! /bin/sh
# Wing FTP Server 2003-2020 wftpserver.com All Rights Reserved 
# SETUP SCRIPT FOR SOLARIS

portvalid="0"
adminport="5466"
username="administrator"
password="wingftp"

INITD_WFTP="/etc/init.d/wftpserver"

APPNAME="$0"
while [ -h "$APPNAME" ]; do
        LINK=`ls -ld "$APPNAME"`
        LINK=`expr "$LINK" : '.*-> \(.*\)'`
        if [ "`expr "$link" : '/.*'`" = 0 ]; then
                DIR=`dirname "$APPNAME"`
                APPNAME="$DIR/$LINK"
        else
                APPNAME="$LINK"
        fi
done
WING_HOME=`dirname $APPNAME`
WING_HOME=`cd $WING_HOME && pwd`


alert() {
	echo "$1? [y/N]: \c"
	read MESSAGE
	expr "$MESSAGE" : ' *[yY].*' > /dev/null
}


if [ "$UID" -ne "0" ]; then
  echo "The setup script is required to run under root privileges."
  echo "Please try again like this:  sudo ./setup.sh"
  exit
fi


echo "Welcome to the Wing FTP Server setup wizard!"
echo "Please setup administrator account for Wing FTP Server."
echo "This account is very important as it will be used to administrate your server."
echo "Enter your administrator name: \c"
read username
while [ -z "$username" ]; do
   echo "Admin name can not be empty!"
   echo ""
   echo "Enter your administrator name: \c"
   read username
done
echo "Enter your administrator password: \c"
read password
while [ -z "$password" ] || [ `echo $password | wc -c` -lt "9" ]; do
   echo "Admin password must have 8 or more characters!"
   echo ""
   echo "Enter your administrator password: \c"
   read password
done

echo ""
echo "Please specify a port that web based administration will be listening to."
echo "Enter the listener port(default is 5466): \c"
read adminport
if [ -z "$adminport" ]; then
    adminport="5466"
fi


#check whether adminport is a valid port
netstat -an | grep "*."$adminport | grep -i listen || portvalid="1" 1>/dev/null 2>&1
echo "$adminport" |grep '[^0-9]' && portvalid="0" 1>/dev/null 2>&1
while [ -z "$adminport" ] || [ "$portvalid" -eq "0" ] || [ "$adminport" -lt "1" ] || [ "$adminport" -gt "65535" ]; do
    echo "Port $adminport is a invalid port or being used, please stop WingFTP service first."
    echo ""
    echo "Enter the listener port(default is 5466): \c"
    read adminport
    if [ -z "$adminport" ]; then
        adminport="5466"
    fi
    portvalid="0"
    netstat -an | grep "*."$adminport | grep -i listen || portvalid="1" 1>/dev/null 2>&1
    echo "$adminport" |grep '[^0-9]' && portvalid="0" 1>/dev/null 2>&1
done

passmd5=""
if [ -f "/usr/sfw/bin/openssl" ]; then
    passmd5=`echo "$password\c" | /usr/sfw/bin/openssl md5 | sed "s/^.*= //"`
elif [ -f "/usr/local/bin/openssl" ]; then
    passmd5=`echo "$password\c" | /usr/local/bin/openssl md5 | sed "s/^.*= //"`
else
    passmd5="62c8ad0a15d9d1ca38d5dee762a16e01"
    echo "Cannot find program 'openssl' in your system!"
    echo "Please remember your initial admin password: 1234qwer"
    echo "You can change your admin password after installation."
    echo ""
fi

#kill the existed wftpserver process
pkill wftpserver & 1>/dev/null 2>&1


if [ ! -f "$WING_HOME/Data/_ADMINISTRATOR/admins.xml" ]; then
mkdir -p "$WING_HOME/Data/_ADMINISTRATOR" 1>/dev/null 2>&1
touch "$WING_HOME/Data/_ADMINISTRATOR/admins.xml"
cat > "$WING_HOME/Data/_ADMINISTRATOR/admins.xml" <<-EOF
<?xml version="1.0" ?>
<ADMIN_ACCOUNTS Description="Wing FTP Server Admin Accounts">
<ADMIN><Admin_Name>$username</Admin_Name><Password>$passmd5</Password><Type>0</Type><Readonly>0</Readonly></ADMIN>
</ADMIN_ACCOUNTS>
EOF
fi

if [ ! -f "$WING_HOME/Data/_ADMINISTRATOR/settings.xml" ]; then
mkdir -p "$WING_HOME/Data/_ADMINISTRATOR" 1>/dev/null 2>&1
touch "$WING_HOME/Data/_ADMINISTRATOR/settings.xml"
cat > "$WING_HOME/Data/_ADMINISTRATOR/settings.xml" <<-EOF
<?xml version="1.0" ?>
<Administrator Description="Wing FTP Server Administrator Options">
    <HttpPort>$adminport</HttpPort>
    <HttpSecure>0</HttpSecure>
    <SSLName>wftp_default_ssl</SSLName>
    <AdminLogfileEnable>1</AdminLogfileEnable>
    <AdminLogfileFileName>Admin-%Y-%M-%D.log</AdminLogfileFileName>
    <AdminLogfileMaxsize>0</AdminLogfileMaxsize>
    <EnablePortUPnP>0</EnablePortUPnP>
</Administrator>
EOF
fi

temp=`sed -e "s/<\/ADMIN_ACCOUNTS>/<ADMIN><Admin_Name>$username<\/Admin_Name><Password>$passmd5<\/Password><Type>0<\/Type><Readonly>0<\/Readonly><\/ADMIN><\/ADMIN_ACCOUNTS>/" "$WING_HOME/Data/_ADMINISTRATOR/admins.xml"`
cat > "$WING_HOME/Data/_ADMINISTRATOR/admins.xml" <<-EOF
$temp
EOF

temp=`sed -e "s/\(<HttpPort>\).*\(<\/HttpPort>\)/\1$adminport\2/" "$WING_HOME/Data/_ADMINISTRATOR/settings.xml"`
cat > "$WING_HOME/Data/_ADMINISTRATOR/settings.xml" <<-EOF
$temp
EOF

chmod -R 600 "$WING_HOME/Data"

if [ -d "$WING_HOME/session" ]; then
	chmod -R 600 "$WING_HOME/session"
fi

if [ -d "$WING_HOME/session_admin" ]; then
	chmod -R 600 "$WING_HOME/session_admin"
fi

if [ -d "$WING_HOME/Log/Admin" ]; then
	chmod -R 600 "$WING_HOME/Log/Admin"
fi


cat > "$INITD_WFTP" <<-EOF
#!/bin/sh
# Startup script for Wing FTP Server

start()
{
    echo "Starting Wing FTP Server daemon..."
    cd $WING_HOME
    ulimit -n 10240
    ./wftpserver & 1>/dev/null 2>&1
    echo "Wing FTP Server Started."
    exit 0;
}
stop()
{
    echo "Stopping Wing FTP Server daemon..."
    #pkill wftpserver & 1>/dev/null 2>&1
    WFTP_PID=\`ps -ef | grep "\\.\\/wftpserver" | grep -v grep | grep -v service | grep -v init.d | awk '{print \$2}'\`
    if [ ! -z "\$WFTP_PID" ]; then
       kill -9 \$WFTP_PID & 1>/dev/null 2>&1
    fi
    echo "Wing FTP Server Stopped."
}
restart()
{
    echo "Restarting Wing FTP Server daemon..."
    #pkill wftpserver & 1>/dev/null 2>&1
    WFTP_PID=\`ps -ef | grep "\\.\\/wftpserver" | grep -v grep | grep -v service | grep -v init.d | awk '{print \$2}'\`
    if [ ! -z "\$WFTP_PID" ]; then
       kill -9 \$WFTP_PID & 1>/dev/null 2>&1
    fi
    echo "Wing FTP Server Stopped."
    cd $WING_HOME
    ulimit -n 10240
    ./wftpserver & 1>/dev/null 2>&1
    echo "Wing FTP Server Started."
    exit 0;
}

case "\$1" in
start)
    start
    ;;
stop)
    stop
    ;;
restart)
    restart
    ;;
*)
    echo "WingFTPServer Usage: /etc/init.d/wftpserver [start|stop|restart]"
    exit 0;
esac

EOF

chmod +x "$INITD_WFTP"



set 0 1
for i in "$@"; do
	ln -s "$INITD_WFTP" "/etc/rc$i.d/K10wftpserver" 
done
set 2 3
for i in "$@"; do
	ln -s "$INITD_WFTP" "/etc/rc$i.d/S99wftpserver" 
done


echo ""
echo "Wing FTP Server has been installed successfully!"
echo "You can manage your server at http://YourIP:$adminport via web browser."
echo "Server Usage: /etc/init.d/wftpserver [start|stop|restart]"

alert "Do you want to start Wing FTP Server now?"
if [ "$?" -eq "0" ]; then
	cd $WING_HOME
	./wftpserver & 1>/dev/null 2>&1
fi
